pub enum QueryExpressionValue {
Length(Length),
Integer(i32),
Float(CSSFloat),
BoolInteger(bool),
NumberRatio(Ratio),
Resolution(Resolution),
Enumerated(KeywordDiscriminant),
Keyword(CSSWideKeyword),
Percentage(Percentage),
Angle(Angle),
Time(Time),
Custom(DashedIdent),
}Expand description
A value found or expected in a expression.
FIXME(emilio): How should calc() serialize in the Number / Integer / BoolInteger / NumberRatio case, as computed or as specified value?
If the first, this would need to store the relevant values.
See: https://github.com/w3c/csswg-drafts/issues/1968
Variants
Length(Length)
A length.
Integer(i32)
An integer.
Float(CSSFloat)
A floating point value.
BoolInteger(bool)
A boolean value, specified as an integer (i.e., either 0 or 1).
NumberRatio(Ratio)
A single non-negative number or two non-negative numbers separated by ‘/’, with optional whitespace on either side of the ‘/’.
Resolution(Resolution)
A resolution.
Enumerated(KeywordDiscriminant)
An enumerated value, defined by the variant keyword table in the
feature’s mData member.
Keyword(CSSWideKeyword)
Value types only used by style-range query expressions, not feature queries. A CSS-wide keyword.
Percentage(Percentage)
A percentage.
Angle(Angle)
An angle.
Time(Time)
A time value.
Custom(DashedIdent)
A custom property name.
Implementations
Sourceimpl QueryExpressionValue
impl QueryExpressionValue
fn to_css<W>(
&self,
dest: &mut CssWriter<'_, W>,
for_expr: Option<&QueryFeatureExpression>,
) -> Resultwhere
W: Write,
fn parse<'i, 't>( for_feature: &QueryFeatureDescription, context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<QueryExpressionValue, ParseError<'i>>
fn parse_for_style_range<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Self, ParseError<'i>>