pub enum QueryStyleRange {
StyleRange2 {
value1: QueryExpressionValue,
op1: Operator,
value2: QueryExpressionValue,
},
StyleRange3 {
value1: QueryExpressionValue,
op1: Operator,
value2: QueryExpressionValue,
op2: Operator,
value3: QueryExpressionValue,
},
}Expand description
https://drafts.csswg.org/css-conditional-5/#typedef-style-range
Variants
StyleRange2
A style-range for style container queries with two values (val1 OP val2).
StyleRange3
A style-range for style container queries with three values (val1 OP val2 OP val3).
Implementations
Sourceimpl QueryStyleRange
impl QueryStyleRange
Sourcepub fn parse<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Self, ParseError<'i>>
pub fn parse<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Self, ParseError<'i>>
Parses the following range syntax:
value
This is only used when parsing @container style() queries; the feature_type and index is hardcoded (and ignored).
Sourcepub fn evaluate(&self, context: &Context<'_>) -> KleeneValue
pub fn evaluate(&self, context: &Context<'_>) -> KleeneValue
Returns whether this style-range query evaluates to true for the given context.
fn resolve_value( value: &QueryExpressionValue, context: &Context<'_>, visited_set: &mut PrecomputedHashSet<DashedIdent>, ) -> Option<Component>
fn resolve_universal( css_text: &str, url_data: &UrlExtraData, context: &Context<'_>, visited_set: &mut PrecomputedHashSet<DashedIdent>, ) -> Option<Component>
fn compare_values( value1: Option<&Component>, value2: Option<&Component>, ) -> Option<Ordering>